# harborapi.ext.artifact

Module that defines the `ArtifactInfo` class that aggregates information about an artifact from several Harbor API models.

::: harborapi.ext.artifact
    options:
        merge_init_into_class: false
        show_if_no_docstring: false
        show_source: true
        show_bases: true
        <!-- members:
            - __init__ -->
